@@ -12,12 +12,13 @@ gzip -c ../target/release/libpact_ffi.a > ../target/artifacts/libpact_ffi-linux-
 openssl dgst -sha256 -r ../target/artifacts/libpact_ffi-linux-x86_64.a.gz > ../target/artifacts/libpact_ffi-linux-x86_64.a.gz.sha256
 
 echo -- Generate the header files --
-rustup component add rustfmt --toolchain nightly-x86_64-unknown-linux-gnu
-rustup run nightly cbindgen \
+rustup toolchain install nightly-2022-04-12
+rustup component add rustfmt --toolchain nightly-2022-04-12-x86_64-unknown-linux-gnu
+rustup run nightly-2022-04-12 cbindgen \
   --config cbindgen.toml \
   --crate pact_ffi \
   --output include/pact.h
-rustup run nightly cbindgen \
+rustup run nightly-2022-04-12 cbindgen \
   --config cbindgen-c++.toml \
   --crate pact_ffi \
   --output include/pact-cpp.h
