@@ -222,7 +222,8 @@ async fn handle_matches(matches: &clap::ArgMatches<'_>) -> Result<(), i32> {
       request_filter: None::<Arc<NullRequestFilterExecutor>>,
       disable_ssl_verification: matches.is_present("disable-ssl-verification"),
       request_timeout: matches.value_of("request-timeout")
-        .map(|t| t.parse::<u64>().unwrap_or(5000)).unwrap_or(5000)
+        .map(|t| t.parse::<u64>().unwrap_or(5000)).unwrap_or(5000),
+      custom_headers: Default::default()
     };
 
     let publish_options = if matches.is_present("publish") {
